apc.indiv.design.model <- function(apc.indiv.design.collinear, 
                                   model.design = "APC",
                                   dep.var = NULL, covariates = NULL){
  ##################
  # This function reduces the collinear design matrix to the design 
  # matrix for the desired model
  ##################
  # Step 1: set-up
  # check model design
  design.list <- c("APC", "AP", "AC", "PC", "Ad", "Pd", "Cd", "A",
                   "P", "C", "t", "tA", "tP", "tC", "1")
  if (!isTRUE(model.design %in% design.list))
    stop("model.design not recognised")
  
  # Extract elements from apc.indiv.design.collinear
  structure.design.collinear <- 
    apc.indiv.design.collinear$structure.design.collinear 
  full.design.collinear <- 
    apc.indiv.design.collinear$full.design.collinear
  
  # check covariates
  missing.covariates <- covariates[!covariates %in% 
                                     names(full.design.collinear)]
  if(!length(missing.covariates)==0)
    stop("some listed covariates are not in dataset")
  
  # get double differences
  set.coh.DDs <- colnames(structure.design.collinear)[grep(
    "^DD_cohort_", colnames(structure.design.collinear))]
  set.age.DDs <- colnames(structure.design.collinear)[grep(
    "^DD_age_", colnames(structure.design.collinear))]
  set.per.DDs <- colnames(structure.design.collinear)[grep(
    "^DD_period_", colnames(structure.design.collinear))]
  ##################
  # Step 2: Select model inclusions
  if(model.design=="APC")	{	slopes <- c(1,0,1); difdif <- c(1,1,1);	}
  if(model.design=="AP" )	{	slopes <- c(1,0,1); difdif <- c(1,1,0);	}
  if(model.design=="AC" )	{	slopes <- c(1,0,1); difdif <- c(1,0,1);	}
  if(model.design=="PC" )	{	slopes <- c(1,0,1); difdif <- c(0,1,1);	}
  if(model.design=="Ad" )	{	slopes <- c(1,0,1); difdif <- c(1,0,0);	}
  if(model.design=="Pd" )	{	slopes <- c(1,0,1); difdif <- c(0,1,0);	}
  if(model.design=="Cd" )	{	slopes <- c(1,0,1); difdif <- c(0,0,1);	}
  if(model.design=="A"  )	{	slopes <- c(1,0,0); difdif <- c(1,0,0);	}
  if(model.design=="P"  )	{	slopes <- c(0,1,0); difdif <- c(0,1,0);	}
  if(model.design=="C"  )	{	slopes <- c(0,0,1); difdif <- c(0,0,1);	}
  if(model.design=="t"  )	{	slopes <- c(1,0,1); difdif <- c(0,0,0);	}
  if(model.design=="tA" )	{	slopes <- c(1,0,0); difdif <- c(0,0,0);	}
  if(model.design=="tP" )	{	slopes <- c(0,1,0); difdif <- c(0,0,0);	}
  if(model.design=="tC" )	{	slopes <- c(0,0,1); difdif <- c(0,0,0);	}
  if(model.design=="1"  )	{	slopes <- c(0,0,0); difdif <- c(0,0,0);	}
  
  incl <- vector(mode="character")
  incl <- c(incl, "level")
  if (slopes[1]) {incl <- c(incl, "age slope")}
  if (slopes[2]) {incl <- c(incl, "period slope")}
  if (slopes[3]) {incl <- c(incl, "cohort slope")}
  if (difdif[1]) {incl <- c(incl, set.age.DDs)}
  if (difdif[2]) {incl <- c(incl, set.per.DDs)}
  if (difdif[3]) {incl <- c(incl, set.coh.DDs)}
  
  full.inclusion <- names(full.design.collinear) %in% c(incl, covariates)
  final.design <- full.design.collinear[full.inclusion]
  
  # warn if no DV specification. No stop because can introduce DV in fit stage
  if (is.null(dep.var)){
    warning("Dependent variable unspecified")
    DV <- dep.var   # ie assign NULL
  } else DV <- full.design.collinear[dep.var]
  ##################
  # Return valuables
  valuables <- list(full.design = final.design,
                    DV = DV,
                    slopes = slopes,
                    difdif = difdif,
                    xi.dim = length(incl),
                    model.design = model.design,
                    
                    unit = apc.indiv.design.collinear$unit,
                    age1 = apc.indiv.design.collinear$age1,
                    per1 = apc.indiv.design.collinear$per1,
                    coh1 = apc.indiv.design.collinear$coh1,
                    age.max = apc.indiv.design.collinear$age.max,
                    per.max = apc.indiv.design.collinear$per.max,
                    coh.max = apc.indiv.design.collinear$coh.max,
                    per.zero = apc.indiv.design.collinear$per.zero,
                    per.odd = apc.indiv.design.collinear$per.odd,
                    U = apc.indiv.design.collinear$U)
  return(valuables)
}